#!/usr/bin/env python

# from os import open, write, read
import Numeric


def write_ermapper_header(ofile, datum = 'AGD66', projection = 'GEOGRAPHIC',
                          coordinate_type = 'LL', rotation = '0:0:0.0',
                          cell_type = 'IEEE4ByteReal', null_value = '-99999',
                          x_dim = '100', x_ll = '0:0:0', y_dim = '100', y_ll = '0:0:0',
                          num_lines = '3', num_cells = '4', num_bands = '1',
                          band_id = 'band1'):

    # Determine if the dataset is in lats/longs or eastings/northings and set header parameters
    # accordingly
    if coordinate_type is 'LL':
        X_Class = 'Longitude'
        Y_Class = 'Latitude'
    elif coordinate_type is 'EN':
        X_Class = 'Eastings'
        Y_Class = 'Northings'

    # open the header file for writing to
    fid = open(ofile,'wt')

    # Begin writing the header
    fid.write('DatasetHeader Begin\n')
    fid.write('\tVersion\t\t\t= "6.4"\n')
    fid.write('\tDatasetType\t\t= ERStorage\n')
    fid.write('\tDataType\t\t= Raster\n')
    fid.write('\tByteOrder\t\t= LSBFirst\n')

    # Write the coordinate space information
    fid.write('\tCoordinateSpace Begin\n')
    fid.write('\t\tDatum\t\t\t = "' + datum + '"\n')
    fid.write('\t\tProjection\t\t = "' + projection + '"\n')
    fid.write('\t\tCoordinateType\t = ' + coordinate_type + '\n')
    fid.write('\t\tRotation\t\t = ' + rotation + '\n')
    fid.write('\tCoordinateSpace End\n')

    # Write the raster information
    fid.write('\tRasterInfo Begin\n')
    fid.write('\t\tCellType\t\t\t = ' + cell_type + '\n')
    fid.write('\t\tNullCellValue\t\t = ' + null_value + '\n')
    fid.write('\t\tRegistrationCellX\t\t = 0\n')
    fid.write('\t\tRegistrationCellY\t\t = ' + str(int(num_lines) - 1) +'\n')
    # Write the cellsize information
    fid.write('\t\tCellInfo Begin\n')
    fid.write('\t\t\tXDimension\t\t\t = ' + x_dim + '\n')
    fid.write('\t\t\tYDimension\t\t\t = ' + y_dim + '\n')
    fid.write('\t\tCellInfo End\n')
    # Continue with wrting the raster information
    fid.write('\t\tNrOfLines\t\t\t = ' + num_lines + '\n')
    fid.write('\t\tNrOfCellsPerLine\t = ' + num_cells + '\n')
    # Write the registration coordinate information
    fid.write('\t\tRegistrationCoord Begin\n')
    fid.write('\t\t\t' + X_Class + '\t\t\t = ' + x_ll + '\n')
    fid.write('\t\t\t' + Y_Class + '\t\t\t = ' + y_ll + '\n')
    fid.write('\t\tRegistrationCoord End\n')
    # Continue with wrting the raster information
    fid.write('\t\tNrOfBands\t\t\t = ' + num_bands + '\n')
    fid.write('\t\tBandID Begin\n')
    fid.write('\t\t\tValue\t\t\t\t = "' + band_id + '"\n')
    fid.write('\t\tBandID End\n')
    fid.write('\tRasterInfo End\n')
    fid.write('DatasetHeader End\n')
    
    fid.close
                          

def write_ermapper_data(grid, ofile, data_format = Numeric.Float32):
    # Convert the array to data_format (default format is Float32)
    grid_as_float = grid.astype(data_format)

    # Convert array to a string for writing to output file
    output_string = grid_as_float.tostring()

    # open output file in a binary format and write the output string
    fid = open(ofile,'wb')
    fid.write(output_string)
    fid.close()


def read_ermapper_data(ifile, data_format = Numeric.Float32):
    # open input file in a binary format and read the input string
    fid = open(ifile,'rb')
    input_string = fid.read()
    fid.close()

    # convert input string to required format (Note default format is Numeric.Float32)
    grid_as_float = Numeric.fromstring(input_string,data_format)
    return grid_as_float

def create_default_header(header):
    # fill any blanks in a header dictionary with default values
    # input parameters:
    # header:   a dictionary containing fields that are not meant
    #           to be filled with default values
    
##    projection = 'GEOGRAPHIC',
##                          coordinate_type = 'LL', rotation = '0:0:0.0',
##                          cell_type = 'IEEE4ByteReal', null_value = '-99999',
##                          x_dim = '100', x_ll = '0:0:0', y_dim = '100', y_ll = '0:0:0',
##                          num_lines = '3', num_cells = '4', num_bands = '1',
##                          band_id = 'band1')
    if not header.has_key('datum'):
        header['datum'] = 'GDA94'
    if not header.has_key('projection'):
        header['datum'] = 'GEOGRAPHIC'        

    return header    
                          
    


    
